@@ -4,6 +4,7 @@
 #' @param ...             Objects to be iterated in each function call
 #' @param const           A list of constant arguments passed to each function call
 #' @param export          List of objects to be exported to the worker
+#' @param pkgs            Character vector of packages to load on the worker
 #' @param seed            A seed to set for each function call
 #' @param memory          Short for template=list(memory=value)
 #' @param template        A named list of values to fill in template
@@ -19,6 +20,7 @@
 #'                        defaults to 100 chunks per worker or max. 10 kb per chunk
 #' @param timeout         Maximum time in seconds to wait for worker (default: Inf)
 #' @param max_calls_worker  Maxmimum number of function calls that will be sent to one worker
+#' @param verbose         Print status messages and progress bar (default: TRUE)
 #' @return                A list of whatever `fun` returned
 #' @export
 #'
@@ -34,10 +36,11 @@
 #'     mutate(area = Q(`*`, e1=Sepal.Length, e2=Sepal.Width, n_jobs=1))
 #' # iris with an additional column 'area'
 #' }
-Q = function(fun, ..., const=list(), export=list(), seed=128965,
+Q = function(fun, ..., const=list(), export=list(), pkgs=c(), seed=128965,
         memory=NULL, template=list(), n_jobs=NULL, job_size=NULL,
         split_array_by=-1, rettype="list", fail_on_error=TRUE, workers=NULL,
-        log_worker=FALSE, chunk_size=NA, timeout=Inf, max_calls_worker=Inf) {
+        log_worker=FALSE, chunk_size=NA, timeout=Inf, max_calls_worker=Inf,
+        verbose=TRUE) {
 
     split_arrays = function(x) {
         if (is.array(x))
@@ -52,6 +55,7 @@ Q = function(fun, ..., const=list(), export=list(), seed=128965,
            df = df,
            const = const,
            export = export,
+           pkgs = pkgs,
            seed = seed,
            memory = memory,
            template = template,
@@ -63,5 +67,6 @@ Q = function(fun, ..., const=list(), export=list(), seed=128965,
            log_worker = log_worker,
            chunk_size = chunk_size,
            timeout = timeout,
-           max_calls_worker = max_calls_worker)
+           max_calls_worker = max_calls_worker,
+           verbose = verbose)
 }
