@@ -39,14 +39,16 @@ has_connectivity = function(host, protocol="tcp") {
     FALSE
 }
 
+ssh_opts = "-oPasswordAuthentication=no -oChallengeResponseAuthentication=no"
+
 has_ssh = function(host) {
-    status = system(paste("ssh", host, "'exit'"), wait=TRUE,
+    status = system(paste("ssh", ssh_opts, host, "'exit'"), wait=TRUE,
                     ignore.stdout=TRUE, ignore.stderr=TRUE)
     status == 0
 }
 
 has_ssh_cmq = function(host) {
-    status = system(paste("ssh", host, "'R -e \"library(clustermq)\"'"),
+    status = system(paste("ssh", ssh_opts, host, "'R -e \"library(clustermq)\"'"),
                     wait=TRUE, ignore.stdout=TRUE, ignore.stderr=TRUE)
     status == 0
 }
